<?php
/*
* 2007-2013 PrestaShop  
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
*         DISCLAIMER   *
* *************************************** */
/* Do not edit or add to this file if you wish to upgrade Prestashop to newer
* versions in the future.
* ****************************************************
* @category   Belvg
* @package    Belvg_FAQ
* @author    Alexander Simonchik <support@belvg.com>
* @site
* @copyright  Copyright (c) 2010 - 2013 BelVG LLC. (http://www.belvg.com)
* @license    http://store.belvg.com/BelVG-LICENSE-COMMUNITY.txt 
*/

class SC extends ObjectModel
{
    /** @var string Name */
    public $content;
    public $title;
    public $position;
    public $active;
	public $info;

    /**
     * @see ObjectModel::$definition
     */
    public static $definition = array(
        'table' => 'sctrl_fisc',
        'primary' => 'id_sctrl_fisc',
        'multilang' => TRUE,
        'fields' => array(
            'position' =>           array('type' => self::TYPE_INT),
            'active' =>             array('type' => self::TYPE_BOOL),
			'info' =>             array('type' => self::TYPE_STRING),
            // Lang fields
            'title' =>          array('type' => self::TYPE_STRING, 'lang' => true, 'validate' => 'isGenericName', 'required' => true, 'size' => 128),
            'content' =>            array('type' => self::TYPE_HTML, 'lang' => TRUE, 'validate' => 'isString', 'size' => 3999999999999),
        ),
    );

    public function add($autodate = TRUE, $null_values = FALSE)
    {
        $this->position = self::getLastPosition();
        return parent::add($autodate, TRUE);
    }

    public function update($null_values = FALSE)
    {
        if (parent::update($null_values)) {
            return $this->cleanPositions();
        }
        
        return FALSE;
    }

    public function delete()
    {
        if (parent::delete()) {
            return $this->cleanPositions();
        }
        
        return FALSE;
    }
    
    public static function getLastPosition()
    {
        $sql = '
        SELECT MAX(position) + 1
        FROM `'._DB_PREFIX_.'sctrl_fisc`';

        return (Db::getInstance()->getValue($sql));
    }

	
    public static function cleanPositions()
    {
        $sql = '
        SELECT `id_sctrl_fisc`
        FROM `'._DB_PREFIX_.'sctrl_fisc`
        ORDER BY `position`';

        $result = Db::getInstance()->executeS($sql);

        for ($i = 0, $total = count($result); $i < $total; ++$i) {
            $sql = 'UPDATE `'._DB_PREFIX_.'sctrl_fisc`
                    SET `position` = '.(int)$i.'
                    WHERE `id_sctrl_fisc` = '.(int)$result[$i]['id_sctrl_fisc'];
            Db::getInstance()->execute($sql);
        }
        
        return TRUE;
    }
    
    public function updatePosition($way, $position)
    {
        if (!$res = Db::getInstance()->executeS('
            SELECT cp.`id_sctrl_fisc`, cp.`position`
            FROM `'._DB_PREFIX_.'sctrl_fisc` cp
            ORDER BY cp.`position` ASC'
        )) {
            return FALSE;
        }
        
        foreach ($res as $faq) {
            if ((int)$faq['id_sctrl_fisc'] == (int)$this->id) {
                $moved_faq = $faq;
            }
        }

        if (!isset($moved_faq) || !isset($position)) {
            return FALSE;
        }

        // < and > statements rather than BETWEEN operator
        // since BETWEEN is treated differently according to databases
        return (Db::getInstance()->execute('
            UPDATE `'._DB_PREFIX_.'sctrl_fisc`
            SET `position`= `position` '.($way ? '- 1' : '+ 1').'
            WHERE `position`
            '.($way
                ? '> '.(int)$moved_faq['position'].' AND `position` <= '.(int)$position
                : '< '.(int)$moved_faq['position'].' AND `position` >= '.(int)$position))
        && Db::getInstance()->execute('
            UPDATE `'._DB_PREFIX_.'sctrl_fisc`
            SET `position` = '.(int)$position.'
            WHERE `id_sctrl_fisc` = '.(int)$moved_faq['id_sctrl_fisc']));
    }
}